summaryrefslogtreecommitdiff
path: root/src/zipmap.c
diff options
context:
space:
mode:
authorJason Davies <jason@jasondavies.com>2011-11-01 19:57:51 +0000
committerJason Davies <jason@jasondavies.com>2011-11-01 19:58:09 +0000
commitb91cbf66bb527fbc7eef8079e9153fa5357186e2 (patch)
tree9cfb71a57d56103d6e92a15fb2749c9097be2215 /src/zipmap.c
parentef23f3ac920c4cc1f403a2765455e455b03101bd (diff)
downloadredis-b91cbf66bb527fbc7eef8079e9153fa5357186e2.tar.gz
Fix minor typos.
Diffstat (limited to 'src/zipmap.c')
-rw-r--r--src/zipmap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/zipmap.c b/src/zipmap.c
index 9f0fc7181..65ed29c89 100644
--- a/src/zipmap.c
+++ b/src/zipmap.c
@@ -298,7 +298,7 @@ unsigned char *zipmapDel(unsigned char *zm, unsigned char *key, unsigned int kle
return zm;
}
/* Call it before to iterate trought elements via zipmapNext() */
unsigned char *zipmapRewind(unsigned char *zm) {
return zm+1;
}
@@ -452,7 +452,7 @@ int main(void) {
vlen, vlen, value);
}
}
- printf("\nIterate trought elements:\n");
+ printf("\nIterate through elements:\n");
{
unsigned char *i = zipmapRewind(zm);
unsigned char *key, *value;
@@ -298,7 +298,7 @@ unsigned char *zipmapDel(unsigned char *zm, unsigned char *key, unsigned int kle
return zm;
}
-/* Call it before to iterate trought elements via zipmapNext() */
+/* Call before iterating through elements via zipmapNext() */
unsigned char *zipmapRewind(unsigned char *zm) {
return zm+1;